/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.prefs.Preferences;

import javax.swing.JCheckBox;
import javax.swing.JTextField;

/**
 * Generates dialog box for changing print options
 */
public class PrintOptions extends javax.swing.JDialog {

	/** A return status code - returned if Cancel button has been pressed */
	public static final int RET_CANCEL = 0;

	/** A return status code - returned if OK button has been pressed */
	public static final int RET_OK = 1;

	private PrintPreview pv;

	private String date;

	private String header;

	private String comment;

	private String legend;

	private boolean printDate;

	private boolean printHeader;

	private boolean printComment;

	private boolean printLegend;

	private boolean printLegendBorder;

	private Preferences printPreferences = null;

	/**
	 * Default constructor
	 * 
	 * @param parent
	 *            parent frame
	 * @param p
	 *            print preview
	 */
	public PrintOptions(javax.swing.JDialog parent, PrintPreview p) {
		super(parent, true);
		initComponents();

		pack();
		setResizable(false);
		setLocationRelativeTo(getOwner());
	}

	/**
	 * Returns status of this dialog
	 * 
	 * @return the return status of this dialog - one of RET_OK or RET_CANCEL
	 */
	public int getReturnStatus() {
		return returnStatus;
	}

	private void initComponents() {
		GridBagConstraints gridBagConstraints8 = new GridBagConstraints();
		gridBagConstraints8.insets = new Insets(2, 0, 0, 0);
		gridBagConstraints8.gridy = 3;
		gridBagConstraints8.ipadx = 16;
		gridBagConstraints8.anchor = GridBagConstraints.EAST;
		gridBagConstraints8.fill = GridBagConstraints.NONE;
		gridBagConstraints8.gridx = 2;
		GridBagConstraints gridBagConstraints7 = new GridBagConstraints();
		gridBagConstraints7.fill = GridBagConstraints.VERTICAL;
		gridBagConstraints7.gridx = 2;
		gridBagConstraints7.gridy = 3;
		gridBagConstraints7.ipadx = 38;
		gridBagConstraints7.ipady = 4;
		gridBagConstraints7.weightx = 0.0;
		gridBagConstraints7.gridwidth = 1;
		gridBagConstraints7.anchor = GridBagConstraints.WEST;
		gridBagConstraints7.insets = new Insets(2, 0, 2, 0);
		GridBagConstraints gridBagConstraints6 = new GridBagConstraints();
		gridBagConstraints6.insets = new Insets(2, 0, 0, 0);
		gridBagConstraints6.gridy = 3;
		gridBagConstraints6.ipadx = 16;
		gridBagConstraints6.gridx = 0;
		GridBagConstraints gridBagConstraints5 = new GridBagConstraints();
		gridBagConstraints5.fill = GridBagConstraints.VERTICAL;
		gridBagConstraints5.gridx = 2;
		gridBagConstraints5.gridy = 2;
		gridBagConstraints5.ipadx = 119;
		gridBagConstraints5.ipady = 4;
		gridBagConstraints5.weightx = 1.0;
		gridBagConstraints5.insets = new Insets(2, 0, 2, 0);
		GridBagConstraints gridBagConstraints4 = new GridBagConstraints();
		gridBagConstraints4.insets = new Insets(2, 0, 2, 0);
		gridBagConstraints4.gridy = 2;
		gridBagConstraints4.gridx = 0;
		GridBagConstraints gridBagConstraints3 = new GridBagConstraints();
		gridBagConstraints3.fill = GridBagConstraints.VERTICAL;
		gridBagConstraints3.gridx = 2;
		gridBagConstraints3.gridy = 1;
		gridBagConstraints3.ipadx = 119;
		gridBagConstraints3.ipady = 4;
		gridBagConstraints3.weightx = 1.0;
		gridBagConstraints3.insets = new Insets(2, 0, 2, 0);
		GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
		gridBagConstraints2.insets = new Insets(2, 0, 2, 0);
		gridBagConstraints2.gridy = 1;
		gridBagConstraints2.ipadx = 33;
		gridBagConstraints2.gridx = 0;
		GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
		gridBagConstraints1.fill = GridBagConstraints.VERTICAL;
		gridBagConstraints1.gridx = 2;
		gridBagConstraints1.gridy = 0;
		gridBagConstraints1.ipadx = 119;
		gridBagConstraints1.ipady = 4;
		gridBagConstraints1.weightx = 1.0;
		gridBagConstraints1.insets = new Insets(0, 0, 2, 0);
		GridBagConstraints gridBagConstraints = new GridBagConstraints();
		gridBagConstraints.insets = new Insets(0, 0, 2, 0);
		gridBagConstraints.gridy = 0;
		gridBagConstraints.ipadx = 31;
		gridBagConstraints.gridx = 0;

		dateCheckBox = new JCheckBox(ResourceManager.getResource("Print_date"));
		dateField = new JTextField(15);
		headerCheckBox = new JCheckBox(ResourceManager
				.getResource("Print_title"));
		headerField = new JTextField(15);
		commentCheckBox = new JCheckBox(ResourceManager
				.getResource("Print_comment"));
		commentField = new JTextField(15);
		legendCheckBox = new JCheckBox(ResourceManager
				.getResource("Print_legend"));
		legendField = new JTextField(15);
		legendBorderCheckBox = new JCheckBox(ResourceManager
				.getResource("Border"));
		buttonPanel = new javax.swing.JPanel();
		okButton = new javax.swing.JButton();
		cancelButton = new javax.swing.JButton();
		propertyPanel = new javax.swing.JPanel();

		setTitle(ResourceManager.getResource("Print_Options"));
		setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		addWindowListener(new java.awt.event.WindowAdapter() {

			public void windowClosing(java.awt.event.WindowEvent evt) {
				closeDialog();
			}
		});

		buttonPanel
				.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT));

		okButton.setText(ResourceManager.getResource("OK"));
		okButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				okButtonActionPerformed();
			}
		});

		buttonPanel.add(okButton);

		cancelButton.setText(ResourceManager.getResource("Cancel"));
		cancelButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				cancelButtonActionPerformed();
			}
		});

		buttonPanel.add(cancelButton);
		getContentPane().add(buttonPanel, java.awt.BorderLayout.SOUTH);

		propertyPanel.setLayout(new GridBagLayout());

		propertyPanel.setBorder(new javax.swing.border.EmptyBorder(
				new java.awt.Insets(4, 4, 4, 4)));

		dateCheckBox.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				dateCheckBoxActionPerformed();
			}
		});
		dateCheckBox.setMnemonic('d');
		dateCheckBox.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);

		headerCheckBox.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				headerCheckBoxActionPerformed();
			}
		});
		headerCheckBox.setMnemonic('t');
		headerCheckBox.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);

		commentCheckBox.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				commentCheckBoxActionPerformed();
			}
		});
		commentCheckBox.setMnemonic('c');
		commentCheckBox.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);

		legendCheckBox.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				legendCheckBoxActionPerformed();
			}
		});
		legendCheckBox.setMnemonic('l');
		legendCheckBox.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);

		legendBorderCheckBox.setMnemonic('b');
		legendBorderCheckBox
				.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);

		propertyPanel.add(headerCheckBox, gridBagConstraints);
		propertyPanel.add(headerField, gridBagConstraints1);
		propertyPanel.add(dateCheckBox, gridBagConstraints2);
		propertyPanel.add(dateField, gridBagConstraints3);
		propertyPanel.add(commentCheckBox, gridBagConstraints4);
		propertyPanel.add(commentField, gridBagConstraints5);
		propertyPanel.add(legendCheckBox, gridBagConstraints6);
		propertyPanel.add(legendField, gridBagConstraints7);
		propertyPanel.add(legendBorderCheckBox, gridBagConstraints8);
		getContentPane().add(propertyPanel, java.awt.BorderLayout.CENTER);
	}

	private void dateCheckBoxActionPerformed() {
		dateField.setEnabled(dateCheckBox.isSelected());
	}

	private void headerCheckBoxActionPerformed() {
		headerField.setEnabled(headerCheckBox.isSelected());
	}

	private void commentCheckBoxActionPerformed() {
		commentField.setEnabled(commentCheckBox.isSelected());
	}

	private void legendCheckBoxActionPerformed() {
		legendField.setEnabled(legendCheckBox.isSelected());
		legendBorderCheckBox.setEnabled(legendCheckBox.isSelected());
	}

	private void okButtonActionPerformed() {
		printDate = dateCheckBox.isSelected();
		printHeader = headerCheckBox.isSelected();
		printComment = commentCheckBox.isSelected();
		printLegend = legendCheckBox.isSelected();
		printLegendBorder = legendBorderCheckBox.isSelected();

		printPreferences.putBoolean("print_date", printDate);
		printPreferences.putBoolean("print_header", printHeader);
		printPreferences.putBoolean("print_comment", printComment);
		printPreferences.putBoolean("print_legend", printLegend);
		printPreferences.putBoolean("print_legendborder", printLegendBorder);

		date = dateField.getText();
		header = headerField.getText();
		comment = commentField.getText();
		legend = legendField.getText();

		doClose(RET_OK);
		pv.updatePreview();
	}

	private void cancelButtonActionPerformed() {
		doClose(RET_CANCEL);
	}

	/**
	 * Closes the dialog
	 */
	private void closeDialog() {
		doClose(RET_CANCEL);
	}

	private void doClose(int retStatus) {
		returnStatus = retStatus;
		setVisible(false);
		dispose();
	}

	private javax.swing.JCheckBox dateCheckBox;

	private javax.swing.JTextField dateField;

	private javax.swing.JCheckBox headerCheckBox;

	private javax.swing.JTextField headerField;

	private javax.swing.JCheckBox commentCheckBox;

	private javax.swing.JTextField commentField;

	private javax.swing.JCheckBox legendCheckBox;

	private javax.swing.JTextField legendField;

	private javax.swing.JCheckBox legendBorderCheckBox;

	private javax.swing.JPanel buttonPanel;

	private javax.swing.JButton okButton;

	private javax.swing.JButton cancelButton;

	private javax.swing.JPanel propertyPanel;

	private int returnStatus = RET_CANCEL;

	/**
	 * Sets new view
	 * 
	 * @param p
	 *            print preview
	 */
	public void setView(PrintPreview p) {
		this.pv = p;

		printPreferences = Preferences.userNodeForPackage(this.getClass());

		printDate = printPreferences.getBoolean("print_date", true);
		printHeader = printPreferences.getBoolean("print_header", true);
		printComment = printPreferences.getBoolean("print_comment", true);
		printLegend = printPreferences.getBoolean("print_legend", true);
		printLegendBorder = printPreferences.getBoolean("print_legendborder",
				true);

		dateCheckBox.setSelected(printDate);
		headerCheckBox.setSelected(printHeader);
		commentCheckBox.setSelected(printComment);
		legendCheckBox.setSelected(printLegend);
		legendBorderCheckBox.setSelected(printLegendBorder);

		SimpleDateFormat formatter = new SimpleDateFormat(
				"dd MMM yyyy, hh:mm:ss", Locale.getDefault());

		date = formatter.format(new Date());

		if (pv.getWorkFrame() != null) {
			header = pv.getWorkFrame().getTitle();
			comment = pv.getWorkFrame().getSelectedContent().getComment();
		}

		legend = ResourceManager.getResource("Legend");

		dateField.setText(date);
		headerField.setText(header);
		commentField.setText(comment);
		legendField.setText(legend);

		dateField.setEnabled(dateCheckBox.isSelected());
		headerField.setEnabled(headerCheckBox.isSelected());
		commentField.setEnabled(commentCheckBox.isSelected());
		legendField.setEnabled(legendCheckBox.isSelected());
		legendBorderCheckBox.setEnabled(legendCheckBox.isSelected());

		getRootPane().setDefaultButton(okButton);
	}

	public String getHeader() {
		return header;
	}

	public String getComment() {
		return comment;
	}

	public String getDate() {
		return date;
	}

	public String getLegend() {
		return legend;
	}

	public boolean isPrintComment() {
		return printComment;
	}

	public boolean isPrintDate() {
		return printDate;
	}

	public boolean isPrintLegend() {
		return printLegend;
	}

	public boolean isPrintLegendBorder() {
		return printLegendBorder;
	}

	public boolean isPrintHeader() {
		return printHeader;
	}
}