/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 * 
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this library; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 *  
 */

package com.simulogic.dataview.analysis;

import com.simulogic.dataview.DataChannel;
import com.simulogic.dataview.DataGroup;
import com.simulogic.dataview.DataStorage;
import com.simulogic.dataview.TimeChannel;

/**
 * Class that performes an averaging of several channels.
 */
public class ChannelAvrg {

    /**
     * Returns the average and standard deviation of the number of channels
     * 
     * @param storage DataStorage to operate on
     * @param chn channel number in every sweep to average
     * 
     * @return group with result data
     */
    public static final DataGroup averageTraces(DataStorage storage, int chn) {
        double recs = 0;
        double n = 0;
        double sum = 0;
        double sumofsq = 0;
        double dt = 1.0;

        DataGroup result = new DataGroup("Average", "Channel average");
        DataGroup group = null;
        DataChannel channel = null;

        try {
            for (int i = 0; i < storage.getGroupsSize(); i++) {
                channel = storage.getChannel(i, chn);
                if ((channel != null) && (channel.getAttribute().isNormal()))
                        if (i == 0)
                                dt = ((TimeChannel) storage
                                        .getXChannel(channel)).getRate();
                recs = Math.max(recs, channel.size());
            }

            DataChannel meanChannel = new DataChannel("Average", (int) recs);
            DataChannel deviationChannel = new DataChannel(
                    "Standard Deviation", (int) recs);

            for (int k = 0; k < recs; k++) {
                for (int i = 0; i < storage.getGroupsSize(); i++) {
                    group = storage.getGroup(i);
                    for (int j = 0; j < storage.getChannelsSize(i); j++) {
                        channel = storage.getChannel(i, chn);
                        if ((channel != null)
                                && (channel.getAttribute().isNormal())) {
                            if (k < channel.size()) {
                                sum += channel.getData(k);
                                sumofsq += (channel.getData(k) * channel
                                        .getData(k));
                                n++;
                            }
                        }
                    }
                }

                meanChannel.setData(k, sum / n);
                deviationChannel.setData(k, Math.sqrt((sumofsq - sum / n * sum)
                        / n));

                n = 0;
                sum = 0;
                sumofsq = 0;
            }

            result.addChannel(new TimeChannel(dt, (int) recs));
            result.addChannel(meanChannel);
            result.addChannel(deviationChannel);
        } catch (Exception e) {
        }

        return result;
    }

}