/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview.analysis;

import javax.swing.JComboBox;

import com.simulogic.dataview.DataView;
import com.simulogic.dataview.ResourceManager;

/**
 * Selector for the analysis region of interest.
 * <p>
 * Provides interface to select either between full trace analysis or between
 * specified cursor interval.
 */
public class RegionSelector {

    private javax.swing.JComboBox regionComboBox;

    /**
     * Creates new RegionSelector
     */
    public RegionSelector() {
        regionComboBox = new javax.swing.JComboBox();

        regionComboBox.setModel(new javax.swing.DefaultComboBoxModel(
                new String[] { ResourceManager.getResource("Full_trace"),
                        ResourceManager.getResource("Cursors") + " 1..2",
                        ResourceManager.getResource("Cursors") + " 3..4"}));
    }

    /**
     * Returns selector component
     * 
     * @return selector ComboBox
     */
    public JComboBox getRegionComboBox() {
        return regionComboBox;
    }

    /**
     * Returns region of interest
     * 
     * @return where double[0] = min, double[1] = max
     * @param v data view
     */
    public double[] getLimits(DataView v) {
        double result[] = new double[2];
        int region = regionComboBox.getSelectedIndex();

        double xmin;
        double xmax;

        if (region == 0) {
            // Full Trace
            xmin = v.getStorage().getLimitRectangle().getX();
            xmax = v.getStorage().getLimitRectangle().getX()
			+ v.getStorage().getLimitRectangle().getWidth();
        } else {
            // Cursors 1..2, 3..4
            xmin = v.getCursors().getCursorSlider().getValueAt(region * 2 - 2);
            xmax = v.getCursors().getCursorSlider().getValueAt(region * 2 - 1);

            if (xmin > xmax) {
                double swap = xmin;
                xmin = xmax;
                xmax = swap;
            }
        }
        result[0] = xmin;
        result[1] = xmax;

        return result;
    }

}